unit DatulaApi;

interface
uses
  Windows;

type
  TPLUGININFO = record
    sizeofStruct: cardinal; // size_t
    title: array[0..63] of char;
    version: array[0..15] of char;
    author: array[0..31] of char;
  end;
  PPLUGININFO = ^TPLUGININFO;

  TMainWindowInfo = record
    frameWnd, folderTree, focusBox, messageList, headerPane, viewer: THandle;
  end;

  TPostmanWindowInfo = record
    signatureBox, attachmentBox, languageBox, editorView, attachmentView, signatureView: THandle;
  end;

  TFHandler = procedure;

  function AppendMenu(item: PChar; handler: TFHandler): boolean;
  procedure DeleteMenu(handler: TFHandler);

  procedure GetMainWindow(var info: TMainWindowInfo );
  function GetPostmanWindow(frameWnd: THandle; var info:TPostmanWindowInfo): boolean;
  function GetHeaderText: string;
  function GetBodyText: string;
  procedure RegisterPluginInfo(hInstance:THandle; const info:TPLUGININFO );
  function GetVersion: cardinal;


implementation
type
  TFappendMenu = function(item: PChar; handler: TFHandler): boolean; stdcall;
  TFdeleteMenu = procedure(handler: TFHandler); stdcall;
  TFgetMainWindow = procedure(var frameWnd, folderTree, focusBox, messageList, headerPane, viewer:THandle ); stdcall;
  TFgetPostmanWindow = function(frameWnd: THandle; var signatureBox, attachmentBox, languageBox, editorView, attachmentView, signatureView: THandle): boolean; stdcall;
  TFgetHeaderTextLength = function: cardinal; stdcall;
  TFgetHeaderText = function(textMax:cardinal; buffer:pchar): pchar; stdcall;
  TFgetBodyTextLength = function: cardinal; stdcall;
  TFgetBodyText = function(textMax:cardinal; buffer:pchar): pchar; stdcall;
  TFregisterPluginInfo = procedure(hInstance:THandle; info:PPLUGININFO ); stdcall;
  TFgetVersion = function: cardinal; stdcall;

var
  PFappendMenu:          TFappendMenu;
  PFdeleteMenu:          TFdeleteMenu;
  PFgetMainWindow:       TFgetMainWindow;
  PFgetPostmanWindow:    TFgetPostmanWindow;
  PFgetHeaderTextLength: TFgetHeaderTextLength;
  PFgetHeaderText:       TFgetHeaderText;
  PFgetBodyTextLength:   TFgetBodyTextLength;
  PFgetBodyText:         TFgetBodyText;
  PFregisterPluginInfo:  TFregisterPluginInfo;
  PFgetVersion:          TFgetVersion;

function AppendMenu(item: PChar; handler: TFHandler): boolean;
begin
  result := PFAppendMenu(item, handler);
end;

procedure deleteMenu(handler: TFHandler);
begin
  PFdeleteMenu(handler);
end;

procedure GetMainWindow(var info: TMainWindowInfo);
begin
  PFgetMainWindow(info.frameWnd,info.folderTree,info.focusBox,info.messageList,info.headerPane,info.viewer);
end;

function GetPostmanWindow(frameWnd: THandle; var info: TPostmanWindowInfo): boolean;
begin
  result := PFgetPostmanWindow(frameWnd, info.signatureBox, info.attachmentBox, info.languageBox, info.editorView, info.attachmentView, info.signatureView);
end;

function getHeaderText: string;
var
  len: cardinal;
begin
  len := PFGetHeaderTextLength;
  SetLength(result, len+1);
  pfGetHeaderText( len+1, pchar(result) );
  SetLength(result, len);
end;

function getBodyText: string;
var
  len: cardinal;
begin
  len := PFGetBodyTextLength;
  SetLength(result, len+1);
  pfGetBodyText( len+1, pchar(result) ) ;
  SetLength(result, len);
end;

procedure registerPluginInfo(hInstance:THandle; const info:TPLUGININFO );
begin
  PFregisterPluginInfo(hInstance, @info);
end;

function getVersion: cardinal;
begin
  result := PFgetVersion;
end;


procedure Init;
var
  hInstance: THandle;
begin
  hInstance := GetModuleHandle(nil);
  PFappendMenu :=          TFappendMenu( GetProcAddress(hInstance, 'AppendMenu') );
  PFdeleteMenu :=          TFdeleteMenu( GetProcAddress(hInstance, 'DeleteMenu') );
  PFgetMainWindow :=       TFgetMainWindow( GetProcAddress(hInstance, 'GetMainWindow') );
  PFgetPostmanWindow :=    TFgetPostmanWindow( GetProcAddress(hInstance, 'GetPostmanWindow') );
  PFgetHeaderTextLength := TFgetHeaderTextLength( GetProcAddress(hInstance, 'GetHeaderTextLength') );
  PFgetHeaderText :=       TFgetHeaderText( GetProcAddress(hInstance, 'GetHeaderText') );
  PFgetBodyTextLength :=   TFgetBodyTextLength( GetProcAddress(hInstance, 'GetBodyTextLength') );
  PFgetBodyText :=         TFgetBodyText( GetProcAddress(hInstance, 'GetBodyText') );
  PFregisterPluginInfo :=  TFregisterPluginInfo( GetProcAddress(hInstance, 'RegisterPluginInfo') );
  PFgetVersion :=          TFgetVersion( GetProcAddress(hInstance, 'GetVersion') );
end;

begin
 Init;

End.
