unit DatulaPlugin;

interface
uses
  Windows,
  DatulaApi;

  function DatulaPlugin_Init: boolean; stdcall;
  function DatulaPlugin_Exit: boolean; stdcall;
  procedure DatulaPlugin_OnUpdateView; stdcall;
  procedure DatulaPlugin_OnActivate(hWnd: THandle; nState: Cardinal; bMinimized: boolean); stdcall;
  procedure DatulaPlugin_OnNewPostmanInstance(hWnd: THandle); stdcall;
  procedure DatulaPlugin_OnDeletePostmanInstance(hWnd: THandle); stdcall;
  function DatulaPlugin_GetPluginVersion: cardinal; stdcall;

exports
  DatulaPlugin_Init index 1,
  DatulaPlugin_Exit index 2,
  DatulaPlugin_OnUpdateView index 3,
  DatulaPlugin_OnActivate index 4,
  DatulaPlugin_OnNewPostmanInstance index 5,
  DatulaPlugin_OnDeletePostmanInstance index 6,
  DatulaPlugin_GetPluginVersion	index 7;

type
  TDatulaPlugin = class
  private
    FTitle: string;
    FAuthor: string;
    FVersion: string;
    FVersionNum: cardinal;
  public
    constructor Create( title, author, version: string; versionnum: cardinal );
    function InitSuccess: boolean; virtual;
    function CanExit: boolean; virtual;
    procedure OnUpdateView; virtual;
    procedure OnActivate(hWnd: THandle; nState: Cardinal; bMinimized: boolean); virtual;
    procedure OnNewPostmanInstance(hWnd: THandle); virtual;
    procedure OnDeletePostmanInstance(hWnd: THandle); virtual;
  end;

var
  PluginMain: TDatulaPlugin = nil;


implementation
uses
  SysUtils;

function DatulaPlugin_Init: boolean;
var
  info: TPLUGININFO;
begin
  //Called when DLL is loaded.
  //if (!api.init())
  //        return false;

  if PluginMain = nil then
  begin
    MessageBox(0, 'TDatulaPluginCX^X쐬Ă܂', 'TDatulaPlugin Error', MB_OK or MB_ICONSTOP );
    result := false;
    exit;
  end;

  result := PluginMain.InitSuccess;

  if result then begin
    //Register plugin-info
    info.sizeofStruct := sizeof (TPLUGININFO);
    StrPLCopy( @info.title, PluginMain.FTitle, sizeof(info.title) );
    StrPLCopy( @info.version, PluginMain.FVersion, sizeof(info.version));
    StrPLCopy( @info.author, PluginMain.FAuthor, sizeof(info.author));
    registerPluginInfo(hInstance, info);
  end;
end;

function DatulaPlugin_Exit: boolean;
begin
  //Called when DLL is unloaded.
  result := PluginMain.CanExit;//If you are busy, you may return false;
  if result then begin
    PluginMain.Free;
    PluginMain := nil;
  end;
end;

procedure DatulaPlugin_OnUpdateView;
begin
  //Called when the document is updated.
  //This is equivalent to CView::OnUpdate.
  PluginMain.OnUpdateView;
end;

procedure DatulaPlugin_OnActivate(hWnd: THandle; nState: Cardinal; bMinimized: boolean);
begin
  //Called when the main frame or postman frame are activated.
  //hWnd: The handle of the window which is activated.
  //nState: WA_INACTIVE/WA_ACTIVE/WA_CLICKACTIVE
  //bMinimized: The window is iconified.
  PluginMain.OnActivate(hWnd, nState, bMinimized);
end;
procedure DatulaPlugin_OnNewPostmanInstance(hWnd: THandle);
begin
  //Called when Postman is created.
  PluginMain.OnNewPostmanInstance(hWnd);
end;

procedure DatulaPlugin_OnDeletePostmanInstance(hWnd: THandle);
begin
  //Called when Postman is deleted.
  PluginMain.OnDeletePostmanInstance(hWnd);
end;

function DatulaPlugin_GetPluginVersion: cardinal;
begin
  //Called at anytime.
  result := PluginMain.FVersionNum;
end;

{TDatulaPlugin}

constructor TDatulaPlugin.Create( title, author, version: string; versionnum: cardinal );
begin
  FTitle := title;
  FAuthor := author;
  FVersion := version;
  FVersionNum := versionnum;
end;

function TDatulaPlugin.InitSuccess: boolean;
begin
  result := true;
end;

function TDatulaPlugin.CanExit: boolean;
begin
  result := true;
end;

procedure TDatulaPlugin.OnActivate(hWnd: THandle; nState: Cardinal;
  bMinimized: boolean);
begin
  // empty
end;

procedure TDatulaPlugin.OnDeletePostmanInstance(hWnd: THandle);
begin
  // empty
end;

procedure TDatulaPlugin.OnNewPostmanInstance(hWnd: THandle);
begin
  // empty
end;

procedure TDatulaPlugin.OnUpdateView;
begin
  // empty
end;

end.
